require 'rails_logtruncate/truncator'
require 'rails_logtruncate/railtie' if defined?(Rails)

module RailsLogtruncate
  extend self

  def truncate(logfile, quota, rails_env = 'production')
    sanitized_quota = begin
                        sanitized_quota = Integer(quota)
                      rescue TypeError
                        0
                      end

    if perform_truncation?(logfile, sanitized_quota, rails_env)
      truncator.call(logfile)
    end
  end

  def truncator=(obj)
    @truncator = obj
  end

  def truncator
    @truncator || RailsLogtruncate::Truncator.new
  end

  private

  def perform_truncation?(file, quota, env)
    quota > 0 &&
      valid_env?(env.to_s) &&
      file_exceeds_quota?(file, quota)
  end

  def valid_env?(env)
    env == 'test' || env == 'development'
  end

  def file_exceeds_quota?(file, quota)
    File.size(file) > quota
  end
end
